@@ -2,7 +2,7 @@
 /**
  * Gollem view script.
  *
- * Copyright 1999-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -24,7 +24,7 @@ $vars = Horde_Variables::getDefaultVariables();
 if ($vars->driver != Gollem::$backend['driver']) {
     Horde::url('login.php')->add(array(
         'backend_key' => $vars->driver,
-        'url' => Horde::selfUrl(true)
+        'url' => Horde::signUrl(Horde::selfUrl(true))
     ))->redirect();
 }
 
